//#define XERR
#include "error.ih"

Error Error::s_error;                         // the singleton object

char const *Error::s_src[]
{
    "configuration file",
    "analysis specification",
    ""
};

char const *Error::s_errorMsg[]
{
    ""                                                              ,   // NONE
    "required `costs:' specification not found"                     ,   // COSTS_SIZE,             
    "probabilities don't sum to 1"                                  ,   // CUMPROB,
    "specification(s) missing for "                                 ,   // INCOMPLETE_SPEC,
    "`tumorIncidence' probabilities must add up to 1"               ,   // INVALID_PROBSUM,        
    "integral number not found (parameter `"                        ,   // MISSING_NR,             
    "multiply specified "                                           ,   // MULTIPLY_SPECIFIED,
    string{"max. number of carrier specifications ("                 +  // N_CARRIERS,
        to_string(END_CARRIERS) + " exceeded"}.c_str()              , 
    "age ranges not consecutive "                                   ,   // NOT_CONSECUTIVE,
    "error in specification (parameter `"                           ,   // SPECIFICATION,          
    "`tumorGrowth:' startDiameter, Mu and Sigma not specified"      ,   // TUMORGROWTH_STARTDIAM,  
    "`tumorGrowth:' no `agegroups' defined"                         ,   // TUMORGROWTH_AGEGROUPS,  
    "at least one `tumorIncidence:' parameter line is required"     ,   // TUMORINCIDENCE_SIZE,    
    "missing `tumorSurvival' types (a, b, c and d are required)\n"  ,   // TUMORSURVIVAL_TYPES,    
};



